.. pywb documentation master file, created by
   sphinx-quickstart on Thu Sep 21 01:58:55 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Webrecorder pywb documentation!
================================

The Webrecorder (:mod:`pywb`) toolkit is a full-featured, advanced web archiving capture and replay framework for python.
It provides command-line tools and an extensible framework for high-fidelity web archive access and creation.
A subset of features provides the basic functionality of a "Wayback Machine".


.. toctree::
   :maxdepth: 3

   manual/usage
   manual/configuring
   manual/access-control
   manual/ui-customization
   manual/localization
   manual/architecture
   manual/apis
   manual/owb-transition
   code/pywb


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
